summaryrefslogtreecommitdiffstats
path: root/libavcodec/wmaprodec.c
diff options
context:
space:
mode:
authorMichael Niedermayer <michaelni@gmx.at>2011-03-21 03:09:46 +0100
committerMichael Niedermayer <michaelni@gmx.at>2011-03-21 03:33:28 +0100
commitd4a50a2100a2b3539d238e64af98e16f47b47a89 (patch)
tree95bc08782f34783dfac34a73142a77adbce4db32 /libavcodec/wmaprodec.c
parent849f80fecbada7c512737e13edec9516541996e3 (diff)
parentcf752d027fafe691951fa00d9c25e2fda032b536 (diff)
downloadffmpeg-streaming-d4a50a2100a2b3539d238e64af98e16f47b47a89.zip
ffmpeg-streaming-d4a50a2100a2b3539d238e64af98e16f47b47a89.tar.gz
Merge remote-tracking branch 'newdev/master'
Merged-by: Michael Niedermayer <michaelni@gmx.at>
Diffstat (limited to 'libavcodec/wmaprodec.c')
-rw-r--r--libavcodec/wmaprodec.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/libavcodec/wmaprodec.c b/libavcodec/wmaprodec.c
index d248ae4..b207e18 100644
--- a/libavcodec/wmaprodec.c
+++ b/libavcodec/wmaprodec.c
@@ -92,6 +92,7 @@
#include "put_bits.h"
#include "wmaprodata.h"
#include "dsputil.h"
+#include "sinewin.h"
#include "wma.h"
/** current decoder limitations */
@@ -1222,6 +1223,7 @@ static int decode_subframe(WMAProDecodeCtx *s)
get_bits_count(&s->gb) - s->subframe_offset);
if (transmit_coeffs) {
+ FFTContext *mdct = &s->mdct_ctx[av_log2(subframe_len) - WMAPRO_BLOCK_MIN_BITS];
/** reconstruct the per channel data */
inverse_channel_transform(s);
for (i = 0; i < s->channels_for_cur_subframe; i++) {
@@ -1246,9 +1248,8 @@ static int decode_subframe(WMAProDecodeCtx *s)
quant, end - start);
}
- /** apply imdct (ff_imdct_half == DCTIV with reverse) */
- ff_imdct_half(&s->mdct_ctx[av_log2(subframe_len) - WMAPRO_BLOCK_MIN_BITS],
- s->channel[c].coeffs, s->tmp);
+ /** apply imdct (imdct_half == DCTIV with reverse) */
+ mdct->imdct_half(mdct, s->channel[c].coeffs, s->tmp);
}
}
OpenPOWER on IntegriCloud